@@ -1,10 +1,11 @@
 package Pcore::Handle::sqlite;
 
-use Pcore -class, -const, -result, -sql;
+use Pcore -class, -const, -result;
 use DBI qw[];
+use Pcore::Handle::DBI::Const qw[:CONST];
 use DBD::SQLite qw[];
 use DBD::SQLite::Constants qw[:file_open];
-use Pcore::Util::Scalar qw[weaken is_blessed_ref looks_like_number is_plain_arrayref is_plain_coderef];
+use Pcore::Util::Scalar qw[weaken is_blessed_ref looks_like_number is_plain_arrayref is_plain_coderef is_blessed_arrayref];
 use Pcore::Util::UUID qw[uuid_str];
 
 # NOTE http://habrahabr.ru/post/149635/
@@ -288,10 +289,10 @@ sub _exec_sth ( $self, $query, @args ) {
 
         # bind types
         for ( my $i = 0; $i <= $#bind; $i++ ) {
-            if ( is_plain_arrayref $bind[$i] ) {
+            if ( is_blessed_arrayref $bind[$i] ) {
                 $sth->bind_param( $i + 1, undef, _get_sqlite_type $bind[$i]->[1] );
 
-                $bind[$i] = $bind[$i]->[0];
+                $bind[$i] = $bind[$i]->[1];
             }
         }
 
@@ -372,10 +373,10 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
             # bind types
             for ( my $i = 0; $i <= $#bind; $i++ ) {
-                if ( is_plain_arrayref $bind[$i] ) {
+                if ( is_blessed_arrayref $bind[$i] ) {
                     $sth->bind_param( $i + 1, undef, _get_sqlite_type $bind[$i]->[1] );
 
-                    $bind[$i] = $bind[$i]->[0];
+                    $bind[$i] = $bind[$i]->[1];
                 }
             }
 
@@ -448,10 +449,10 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
             # bind types
             for ( my $i = 0; $i <= $#bind; $i++ ) {
-                if ( is_plain_arrayref $bind[$i] ) {
+                if ( is_blessed_arrayref $bind[$i] ) {
                     $sth->bind_param( $i + 1, undef, _get_sqlite_type $bind[$i]->[1] );
 
-                    $bind[$i] = $bind[$i]->[0];
+                    $bind[$i] = $bind[$i]->[1];
                 }
             }
 
@@ -681,18 +682,18 @@ sub attach ( $self, $name, $path = undef ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 154                  | Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_get_schema_patch_table_query'      |
+## |    3 | 155                  | Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_get_schema_patch_table_query'      |
 ## |      |                      | declared but not used                                                                                          |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 325                  | Subroutines::ProhibitExcessComplexity - Subroutine "do" with high complexity score (40)                        |
+## |    3 | 326                  | Subroutines::ProhibitExcessComplexity - Subroutine "do" with high complexity score (40)                        |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 412                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
+## |    3 | 413                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 202                  | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |    2 | 203                  | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 290, 374, 450        | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
+## |    2 | 291, 375, 451        | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 606                  | ControlStructures::ProhibitPostfixControls - Postfix control "while" used                                      |
+## |    2 | 607                  | ControlStructures::ProhibitPostfixControls - Postfix control "while" used                                      |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
